@@ -1199,6 +1199,14 @@ struct mapcache_tileset {
    */
   int auto_expire;
 
+  /**
+   * Cache-Control directives to be set for a tiled response (MAPCACHE_REQUEST_GET_TILE)
+   *
+   * complements expiration set by the #expires parameter.
+   * \sa expires
+   */
+  const char *cache_control;
+
   int read_only;
   int subdimension_read_only;
 
@@ -1749,6 +1757,12 @@ struct mapcache_dimension {
   apr_array_header_t* (*get_all_ogc_formatted_entries)(mapcache_context *ctx, mapcache_dimension *dimension,
                        mapcache_tileset *tileset, mapcache_extent *extent, mapcache_grid *grid);
 
+  /**
+   * \brief return all value to override default value
+   */
+  apr_array_header_t* (*get_default_value)(mapcache_context *ctx, mapcache_dimension *dimension,
+                       mapcache_tileset *tileset, mapcache_extent *extent, mapcache_grid *grid);
+
   /**
    * \brief parse the value given in the configuration
    */
