@@ -318,8 +318,9 @@ int ogr_features_intersect_tile(mapcache_context *ctx, mapcache_tile *tile)
 {
   mapcache_metatile *mt = mapcache_tileset_metatile_get(ctx,tile);
   GEOSCoordSequence *mtbboxls = GEOSCoordSeq_create(5,2);
-  GEOSGeometry *mtbbox = GEOSGeom_createLinearRing(mtbboxls);
-  GEOSGeometry *mtbboxg = GEOSGeom_createPolygon(mtbbox,NULL,0);
+  // linearring and polygon creation moved after coords - more recent GEOS seems to assume coordinates are set
+  GEOSGeometry *mtbbox = NULL;
+  GEOSGeometry *mtbboxg = NULL;
   int i;
   int intersects = 0;
   GEOSCoordSeq_setX(mtbboxls,0,mt->map.extent.minx);
@@ -332,6 +333,10 @@ int ogr_features_intersect_tile(mapcache_context *ctx, mapcache_tile *tile)
   GEOSCoordSeq_setY(mtbboxls,3,mt->map.extent.maxy);
   GEOSCoordSeq_setX(mtbboxls,4,mt->map.extent.minx);
   GEOSCoordSeq_setY(mtbboxls,4,mt->map.extent.miny);
+  // moved after coords - more recent GEOS seems to assume coordinates are set
+  mtbbox = GEOSGeom_createLinearRing(mtbboxls);
+  mtbboxg = GEOSGeom_createPolygon(mtbbox,NULL,0);
+
   for(i=0; i<nClippers; i++) {
     const GEOSPreparedGeometry *clipper = clippers[i];
     if(GEOSPreparedIntersects(clipper,mtbboxg)) {
@@ -485,7 +490,23 @@ void cmd_recurse(mapcache_context *cmd_ctx, mapcache_tile *tile)
   if(sig_int_received || error_detected) { //stop if we were asked to stop by hitting ctrl-c
     //remove all items from the queue
     struct seed_cmd entry;
-    while (trypop_queue(&entry)!=APR_EAGAIN) /*do nothing*/;
+    int retry_count = 0;
+    int ret = trypop_queue(&entry);
+    while (ret != APR_EAGAIN) {
+      // try to empty queue with a graceful retreat up to 55 seconds
+      // for retries before forcefully terminating threads
+      if (ret == APR_EOF)
+        break;
+      if (ret != APR_SUCCESS)
+        retry_count++;
+      if (retry_count > 10) {
+        printf("Feed worker threads failed to terminate. Stopping forcefully.\n");
+        apr_queue_interrupt_all(work_queue);
+        break;
+      }
+      apr_sleep(retry_count * 1000000);
+      ret = trypop_queue(&entry);
+    }
     return;
   }
 
@@ -614,7 +635,23 @@ void feed_worker()
       if(sig_int_received || error_detected) { //stop if we were asked to stop by hitting ctrl-c
         //remove all items from the queue
         struct seed_cmd entry;
-        while (trypop_queue(&entry)!=APR_EAGAIN) /* do nothing */;
+        int retry_count = 0;
+        int ret = trypop_queue(&entry);
+        while (ret != APR_EAGAIN) {
+          // try to empty queue with a graceful retreat up to 55 seconds
+          // for retries before forcefully terminating threads
+          if (ret == APR_EOF)
+            break;
+          if (ret != APR_SUCCESS)
+            retry_count++;
+          if (retry_count > 10) {
+            printf("Feed worker threads failed to terminate. Stopping forcefully.\n");
+            apr_queue_interrupt_all(work_queue);
+            break;
+          }
+          apr_sleep(retry_count * 1000000);
+          ret = trypop_queue(&entry);
+        }
         break;
       }
       if(iteration_mode == MAPCACHE_ITERATION_LOG) {
